Index: src/compiler/ast-graph-builder.h |
diff --git a/src/compiler/ast-graph-builder.h b/src/compiler/ast-graph-builder.h |
index 96c1a911565ce0c3fdcf427f886befb55cd00aa2..3b6302d3ddcf86bd719df0d910e28314ddc3e684 100644 |
--- a/src/compiler/ast-graph-builder.h |
+++ b/src/compiler/ast-graph-builder.h |
@@ -169,7 +169,7 @@ class AstGraphBuilder : public AstVisitor { |
// Node creation helpers. |
Node* NewNode(const Operator* op, bool incomplete = false) { |
- return MakeNode(op, 0, static_cast<Node**>(NULL), incomplete); |
+ return MakeNode(op, 0, static_cast<Node**>(nullptr), incomplete); |
} |
Node* NewNode(const Operator* op, Node* n1) { |
@@ -365,7 +365,7 @@ class AstGraphBuilder : public AstVisitor { |
// =========================================================================== |
// The following build methods have the same contract as the above ones, but |
// they can also return {NULL} to indicate that no fragment was built. Note |
// that these are optimizations, disabling any of them should still produce |
// correct graphs. |
@@ -365,7 +365,7 @@ class AstGraphBuilder : public AstVisitor { |
// =========================================================================== |
// The following build methods have the same contract as the above ones, but |
- // they can also return {NULL} to indicate that no fragment was built. Note |
+ // they can also return {nullptr} to indicate that no fragment was built. Note |
// that these are optimizations, disabling any of them should still produce |
// correct graphs. |